#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MaterialField import MaterialField


class AlipayMarketingMaterialCreateModel(object):

    def __init__(self):
        self._material_fields = None
        self._material_name = None
        self._material_spec_id = None
        self._out_biz_no = None

    @property
    def material_fields(self):
        return self._material_fields

    @material_fields.setter
    def material_fields(self, value):
        if isinstance(value, list):
            self._material_fields = list()
            for i in value:
                if isinstance(i, MaterialField):
                    self._material_fields.append(i)
                else:
                    self._material_fields.append(MaterialField.from_alipay_dict(i))
    @property
    def material_name(self):
        return self._material_name

    @material_name.setter
    def material_name(self, value):
        self._material_name = value
    @property
    def material_spec_id(self):
        return self._material_spec_id

    @material_spec_id.setter
    def material_spec_id(self, value):
        self._material_spec_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.material_fields:
            if isinstance(self.material_fields, list):
                for i in range(0, len(self.material_fields)):
                    element = self.material_fields[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.material_fields[i] = element.to_alipay_dict()
            if hasattr(self.material_fields, 'to_alipay_dict'):
                params['material_fields'] = self.material_fields.to_alipay_dict()
            else:
                params['material_fields'] = self.material_fields
        if self.material_name:
            if hasattr(self.material_name, 'to_alipay_dict'):
                params['material_name'] = self.material_name.to_alipay_dict()
            else:
                params['material_name'] = self.material_name
        if self.material_spec_id:
            if hasattr(self.material_spec_id, 'to_alipay_dict'):
                params['material_spec_id'] = self.material_spec_id.to_alipay_dict()
            else:
                params['material_spec_id'] = self.material_spec_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingMaterialCreateModel()
        if 'material_fields' in d:
            o.material_fields = d['material_fields']
        if 'material_name' in d:
            o.material_name = d['material_name']
        if 'material_spec_id' in d:
            o.material_spec_id = d['material_spec_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EcomItemDTO import EcomItemDTO
from alipay.aop.api.domain.EcomSellerDTO import EcomSellerDTO


class AlipayInsSceneEcommercePurchaseRecommendModel(object):

    def __init__(self):
        self._authorized_token = None
        self._item = None
        self._partner_org_id = None
        self._related_subject_type = None
        self._scene_code = None
        self._seller = None
        self._user_client = None

    @property
    def authorized_token(self):
        return self._authorized_token

    @authorized_token.setter
    def authorized_token(self, value):
        self._authorized_token = value
    @property
    def item(self):
        return self._item

    @item.setter
    def item(self, value):
        if isinstance(value, EcomItemDTO):
            self._item = value
        else:
            self._item = EcomItemDTO.from_alipay_dict(value)
    @property
    def partner_org_id(self):
        return self._partner_org_id

    @partner_org_id.setter
    def partner_org_id(self, value):
        self._partner_org_id = value
    @property
    def related_subject_type(self):
        return self._related_subject_type

    @related_subject_type.setter
    def related_subject_type(self, value):
        self._related_subject_type = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, EcomSellerDTO):
            self._seller = value
        else:
            self._seller = EcomSellerDTO.from_alipay_dict(value)
    @property
    def user_client(self):
        return self._user_client

    @user_client.setter
    def user_client(self, value):
        self._user_client = value


    def to_alipay_dict(self):
        params = dict()
        if self.authorized_token:
            if hasattr(self.authorized_token, 'to_alipay_dict'):
                params['authorized_token'] = self.authorized_token.to_alipay_dict()
            else:
                params['authorized_token'] = self.authorized_token
        if self.item:
            if hasattr(self.item, 'to_alipay_dict'):
                params['item'] = self.item.to_alipay_dict()
            else:
                params['item'] = self.item
        if self.partner_org_id:
            if hasattr(self.partner_org_id, 'to_alipay_dict'):
                params['partner_org_id'] = self.partner_org_id.to_alipay_dict()
            else:
                params['partner_org_id'] = self.partner_org_id
        if self.related_subject_type:
            if hasattr(self.related_subject_type, 'to_alipay_dict'):
                params['related_subject_type'] = self.related_subject_type.to_alipay_dict()
            else:
                params['related_subject_type'] = self.related_subject_type
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.user_client:
            if hasattr(self.user_client, 'to_alipay_dict'):
                params['user_client'] = self.user_client.to_alipay_dict()
            else:
                params['user_client'] = self.user_client
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneEcommercePurchaseRecommendModel()
        if 'authorized_token' in d:
            o.authorized_token = d['authorized_token']
        if 'item' in d:
            o.item = d['item']
        if 'partner_org_id' in d:
            o.partner_org_id = d['partner_org_id']
        if 'related_subject_type' in d:
            o.related_subject_type = d['related_subject_type']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'seller' in d:
            o.seller = d['seller']
        if 'user_client' in d:
            o.user_client = d['user_client']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneTaskflowBatchFinishModel(object):

    def __init__(self):
        self._extra_map = None
        self._open_id = None
        self._out_biz_no = None
        self._task_flow_id_list = None
        self._user_id = None

    @property
    def extra_map(self):
        return self._extra_map

    @extra_map.setter
    def extra_map(self, value):
        self._extra_map = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def task_flow_id_list(self):
        return self._task_flow_id_list

    @task_flow_id_list.setter
    def task_flow_id_list(self, value):
        if isinstance(value, list):
            self._task_flow_id_list = list()
            for i in value:
                self._task_flow_id_list.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.extra_map:
            if hasattr(self.extra_map, 'to_alipay_dict'):
                params['extra_map'] = self.extra_map.to_alipay_dict()
            else:
                params['extra_map'] = self.extra_map
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.task_flow_id_list:
            if isinstance(self.task_flow_id_list, list):
                for i in range(0, len(self.task_flow_id_list)):
                    element = self.task_flow_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.task_flow_id_list[i] = element.to_alipay_dict()
            if hasattr(self.task_flow_id_list, 'to_alipay_dict'):
                params['task_flow_id_list'] = self.task_flow_id_list.to_alipay_dict()
            else:
                params['task_flow_id_list'] = self.task_flow_id_list
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneTaskflowBatchFinishModel()
        if 'extra_map' in d:
            o.extra_map = d['extra_map']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'task_flow_id_list' in d:
            o.task_flow_id_list = d['task_flow_id_list']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoanapplyDataUploadModel(object):

    def __init__(self):
        self._biz_no = None
        self._biz_type = None
        self._category = None
        self._data = None
        self._data_provider = None
        self._entity_code = None
        self._entity_name = None
        self._entity_type = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def data_provider(self):
        return self._data_provider

    @data_provider.setter
    def data_provider(self, value):
        self._data_provider = value
    @property
    def entity_code(self):
        return self._entity_code

    @entity_code.setter
    def entity_code(self, value):
        self._entity_code = value
    @property
    def entity_name(self):
        return self._entity_name

    @entity_name.setter
    def entity_name(self, value):
        self._entity_name = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.data:
            if hasattr(self.data, 'to_alipay_dict'):
                params['data'] = self.data.to_alipay_dict()
            else:
                params['data'] = self.data
        if self.data_provider:
            if hasattr(self.data_provider, 'to_alipay_dict'):
                params['data_provider'] = self.data_provider.to_alipay_dict()
            else:
                params['data_provider'] = self.data_provider
        if self.entity_code:
            if hasattr(self.entity_code, 'to_alipay_dict'):
                params['entity_code'] = self.entity_code.to_alipay_dict()
            else:
                params['entity_code'] = self.entity_code
        if self.entity_name:
            if hasattr(self.entity_name, 'to_alipay_dict'):
                params['entity_name'] = self.entity_name.to_alipay_dict()
            else:
                params['entity_name'] = self.entity_name
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoanapplyDataUploadModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'category' in d:
            o.category = d['category']
        if 'data' in d:
            o.data = d['data']
        if 'data_provider' in d:
            o.data_provider = d['data_provider']
        if 'entity_code' in d:
            o.entity_code = d['entity_code']
        if 'entity_name' in d:
            o.entity_name = d['entity_name']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenIotmbsIsvdataQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenIotmbsIsvdataQueryResponse, self).__init__()
        self._content_list = None
        self._list_total_count = None

    @property
    def content_list(self):
        return self._content_list

    @content_list.setter
    def content_list(self, value):
        if isinstance(value, list):
            self._content_list = list()
            for i in value:
                self._content_list.append(i)
    @property
    def list_total_count(self):
        return self._list_total_count

    @list_total_count.setter
    def list_total_count(self, value):
        self._list_total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenIotmbsIsvdataQueryResponse, self).parse_response_content(response_content)
        if 'content_list' in response:
            self.content_list = response['content_list']
        if 'list_total_count' in response:
            self.list_total_count = response['list_total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainFinanceTruspleCreditgrantapplySubmitResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainFinanceTruspleCreditgrantapplySubmitResponse, self).__init__()
        self._inst_credit_grant_id = None
        self._result_status = None

    @property
    def inst_credit_grant_id(self):
        return self._inst_credit_grant_id

    @inst_credit_grant_id.setter
    def inst_credit_grant_id(self, value):
        self._inst_credit_grant_id = value
    @property
    def result_status(self):
        return self._result_status

    @result_status.setter
    def result_status(self, value):
        self._result_status = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainFinanceTruspleCreditgrantapplySubmitResponse, self).parse_response_content(response_content)
        if 'inst_credit_grant_id' in response:
            self.inst_credit_grant_id = response['inst_credit_grant_id']
        if 'result_status' in response:
            self.result_status = response['result_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class AlipayTransferThirdpartyBillCreateRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._amount = None
        self._currency = None
        self._ext_param = None
        self._memo = None
        self._partner_id = None
        self._payee_account = None
        self._payee_type = None
        self._payer_account = None
        self._payer_type = None
        self._payment_id = None
        self._payment_source = None
        self._title = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def payee_account(self):
        return self._payee_account

    @payee_account.setter
    def payee_account(self, value):
        self._payee_account = value
    @property
    def payee_type(self):
        return self._payee_type

    @payee_type.setter
    def payee_type(self, value):
        self._payee_type = value
    @property
    def payer_account(self):
        return self._payer_account

    @payer_account.setter
    def payer_account(self, value):
        self._payer_account = value
    @property
    def payer_type(self):
        return self._payer_type

    @payer_type.setter
    def payer_type(self, value):
        self._payer_type = value
    @property
    def payment_id(self):
        return self._payment_id

    @payment_id.setter
    def payment_id(self, value):
        self._payment_id = value
    @property
    def payment_source(self):
        return self._payment_source

    @payment_source.setter
    def payment_source(self, value):
        self._payment_source = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'alipay.transfer.thirdparty.bill.create'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = json.dumps(obj=self.amount.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['amount'] = self.amount
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = json.dumps(obj=self.currency.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['currency'] = self.currency
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = json.dumps(obj=self.ext_param.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['ext_param'] = self.ext_param
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = json.dumps(obj=self.memo.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['memo'] = self.memo
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = json.dumps(obj=self.partner_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['partner_id'] = self.partner_id
        if self.payee_account:
            if hasattr(self.payee_account, 'to_alipay_dict'):
                params['payee_account'] = json.dumps(obj=self.payee_account.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payee_account'] = self.payee_account
        if self.payee_type:
            if hasattr(self.payee_type, 'to_alipay_dict'):
                params['payee_type'] = json.dumps(obj=self.payee_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payee_type'] = self.payee_type
        if self.payer_account:
            if hasattr(self.payer_account, 'to_alipay_dict'):
                params['payer_account'] = json.dumps(obj=self.payer_account.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payer_account'] = self.payer_account
        if self.payer_type:
            if hasattr(self.payer_type, 'to_alipay_dict'):
                params['payer_type'] = json.dumps(obj=self.payer_type.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payer_type'] = self.payer_type
        if self.payment_id:
            if hasattr(self.payment_id, 'to_alipay_dict'):
                params['payment_id'] = json.dumps(obj=self.payment_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payment_id'] = self.payment_id
        if self.payment_source:
            if hasattr(self.payment_source, 'to_alipay_dict'):
                params['payment_source'] = json.dumps(obj=self.payment_source.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['payment_source'] = self.payment_source
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = json.dumps(obj=self.title.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['title'] = self.title
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.XXXXsdasdasd import XXXXsdasdasd


class ZhimaMerchantTestPracticeResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaMerchantTestPracticeResponse, self).__init__()
        self._dddd = None
        self._sss = None

    @property
    def dddd(self):
        return self._dddd

    @dddd.setter
    def dddd(self, value):
        if isinstance(value, XXXXsdasdasd):
            self._dddd = value
        else:
            self._dddd = XXXXsdasdasd.from_alipay_dict(value)
    @property
    def sss(self):
        return self._sss

    @sss.setter
    def sss(self, value):
        self._sss = value

    def parse_response_content(self, response_content):
        response = super(ZhimaMerchantTestPracticeResponse, self).parse_response_content(response_content)
        if 'dddd' in response:
            self.dddd = response['dddd']
        if 'sss' in response:
            self.sss = response['sss']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PrizeCustomMenu import PrizeCustomMenu
from alipay.aop.api.domain.OpenPromoPrizeDimension import OpenPromoPrizeDimension
from alipay.aop.api.domain.OpenPromoPrizeRelativeTime import OpenPromoPrizeRelativeTime


class OpenPromoPrize(object):

    def __init__(self):
        self._prize_base_rule_amount = None
        self._prize_custom_menu = None
        self._prize_desc = None
        self._prize_detail_img = None
        self._prize_dimension_time = None
        self._prize_end_time = None
        self._prize_logo = None
        self._prize_name = None
        self._prize_relative_time = None
        self._prize_start_time = None
        self._prize_subtitle = None
        self._prize_suitable_shops = None
        self._prize_template_end_time = None
        self._prize_template_start_time = None
        self._prize_terms = None
        self._prize_type = None
        self._prize_worth_amount = None

    @property
    def prize_base_rule_amount(self):
        return self._prize_base_rule_amount

    @prize_base_rule_amount.setter
    def prize_base_rule_amount(self, value):
        self._prize_base_rule_amount = value
    @property
    def prize_custom_menu(self):
        return self._prize_custom_menu

    @prize_custom_menu.setter
    def prize_custom_menu(self, value):
        if isinstance(value, list):
            self._prize_custom_menu = list()
            for i in value:
                if isinstance(i, PrizeCustomMenu):
                    self._prize_custom_menu.append(i)
                else:
                    self._prize_custom_menu.append(PrizeCustomMenu.from_alipay_dict(i))
    @property
    def prize_desc(self):
        return self._prize_desc

    @prize_desc.setter
    def prize_desc(self, value):
        self._prize_desc = value
    @property
    def prize_detail_img(self):
        return self._prize_detail_img

    @prize_detail_img.setter
    def prize_detail_img(self, value):
        self._prize_detail_img = value
    @property
    def prize_dimension_time(self):
        return self._prize_dimension_time

    @prize_dimension_time.setter
    def prize_dimension_time(self, value):
        if isinstance(value, list):
            self._prize_dimension_time = list()
            for i in value:
                if isinstance(i, OpenPromoPrizeDimension):
                    self._prize_dimension_time.append(i)
                else:
                    self._prize_dimension_time.append(OpenPromoPrizeDimension.from_alipay_dict(i))
    @property
    def prize_end_time(self):
        return self._prize_end_time

    @prize_end_time.setter
    def prize_end_time(self, value):
        self._prize_end_time = value
    @property
    def prize_logo(self):
        return self._prize_logo

    @prize_logo.setter
    def prize_logo(self, value):
        self._prize_logo = value
    @property
    def prize_name(self):
        return self._prize_name

    @prize_name.setter
    def prize_name(self, value):
        self._prize_name = value
    @property
    def prize_relative_time(self):
        return self._prize_relative_time

    @prize_relative_time.setter
    def prize_relative_time(self, value):
        if isinstance(value, OpenPromoPrizeRelativeTime):
            self._prize_relative_time = value
        else:
            self._prize_relative_time = OpenPromoPrizeRelativeTime.from_alipay_dict(value)
    @property
    def prize_start_time(self):
        return self._prize_start_time

    @prize_start_time.setter
    def prize_start_time(self, value):
        self._prize_start_time = value
    @property
    def prize_subtitle(self):
        return self._prize_subtitle

    @prize_subtitle.setter
    def prize_subtitle(self, value):
        self._prize_subtitle = value
    @property
    def prize_suitable_shops(self):
        return self._prize_suitable_shops

    @prize_suitable_shops.setter
    def prize_suitable_shops(self, value):
        if isinstance(value, list):
            self._prize_suitable_shops = list()
            for i in value:
                self._prize_suitable_shops.append(i)
    @property
    def prize_template_end_time(self):
        return self._prize_template_end_time

    @prize_template_end_time.setter
    def prize_template_end_time(self, value):
        self._prize_template_end_time = value
    @property
    def prize_template_start_time(self):
        return self._prize_template_start_time

    @prize_template_start_time.setter
    def prize_template_start_time(self, value):
        self._prize_template_start_time = value
    @property
    def prize_terms(self):
        return self._prize_terms

    @prize_terms.setter
    def prize_terms(self, value):
        if isinstance(value, list):
            self._prize_terms = list()
            for i in value:
                self._prize_terms.append(i)
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def prize_worth_amount(self):
        return self._prize_worth_amount

    @prize_worth_amount.setter
    def prize_worth_amount(self, value):
        self._prize_worth_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.prize_base_rule_amount:
            if hasattr(self.prize_base_rule_amount, 'to_alipay_dict'):
                params['prize_base_rule_amount'] = self.prize_base_rule_amount.to_alipay_dict()
            else:
                params['prize_base_rule_amount'] = self.prize_base_rule_amount
        if self.prize_custom_menu:
            if isinstance(self.prize_custom_menu, list):
                for i in range(0, len(self.prize_custom_menu)):
                    element = self.prize_custom_menu[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prize_custom_menu[i] = element.to_alipay_dict()
            if hasattr(self.prize_custom_menu, 'to_alipay_dict'):
                params['prize_custom_menu'] = self.prize_custom_menu.to_alipay_dict()
            else:
                params['prize_custom_menu'] = self.prize_custom_menu
        if self.prize_desc:
            if hasattr(self.prize_desc, 'to_alipay_dict'):
                params['prize_desc'] = self.prize_desc.to_alipay_dict()
            else:
                params['prize_desc'] = self.prize_desc
        if self.prize_detail_img:
            if hasattr(self.prize_detail_img, 'to_alipay_dict'):
                params['prize_detail_img'] = self.prize_detail_img.to_alipay_dict()
            else:
                params['prize_detail_img'] = self.prize_detail_img
        if self.prize_dimension_time:
            if isinstance(self.prize_dimension_time, list):
                for i in range(0, len(self.prize_dimension_time)):
                    element = self.prize_dimension_time[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prize_dimension_time[i] = element.to_alipay_dict()
            if hasattr(self.prize_dimension_time, 'to_alipay_dict'):
                params['prize_dimension_time'] = self.prize_dimension_time.to_alipay_dict()
            else:
                params['prize_dimension_time'] = self.prize_dimension_time
        if self.prize_end_time:
            if hasattr(self.prize_end_time, 'to_alipay_dict'):
                params['prize_end_time'] = self.prize_end_time.to_alipay_dict()
            else:
                params['prize_end_time'] = self.prize_end_time
        if self.prize_logo:
            if hasattr(self.prize_logo, 'to_alipay_dict'):
                params['prize_logo'] = self.prize_logo.to_alipay_dict()
            else:
                params['prize_logo'] = self.prize_logo
        if self.prize_name:
            if hasattr(self.prize_name, 'to_alipay_dict'):
                params['prize_name'] = self.prize_name.to_alipay_dict()
            else:
                params['prize_name'] = self.prize_name
        if self.prize_relative_time:
            if hasattr(self.prize_relative_time, 'to_alipay_dict'):
                params['prize_relative_time'] = self.prize_relative_time.to_alipay_dict()
            else:
                params['prize_relative_time'] = self.prize_relative_time
        if self.prize_start_time:
            if hasattr(self.prize_start_time, 'to_alipay_dict'):
                params['prize_start_time'] = self.prize_start_time.to_alipay_dict()
            else:
                params['prize_start_time'] = self.prize_start_time
        if self.prize_subtitle:
            if hasattr(self.prize_subtitle, 'to_alipay_dict'):
                params['prize_subtitle'] = self.prize_subtitle.to_alipay_dict()
            else:
                params['prize_subtitle'] = self.prize_subtitle
        if self.prize_suitable_shops:
            if isinstance(self.prize_suitable_shops, list):
                for i in range(0, len(self.prize_suitable_shops)):
                    element = self.prize_suitable_shops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prize_suitable_shops[i] = element.to_alipay_dict()
            if hasattr(self.prize_suitable_shops, 'to_alipay_dict'):
                params['prize_suitable_shops'] = self.prize_suitable_shops.to_alipay_dict()
            else:
                params['prize_suitable_shops'] = self.prize_suitable_shops
        if self.prize_template_end_time:
            if hasattr(self.prize_template_end_time, 'to_alipay_dict'):
                params['prize_template_end_time'] = self.prize_template_end_time.to_alipay_dict()
            else:
                params['prize_template_end_time'] = self.prize_template_end_time
        if self.prize_template_start_time:
            if hasattr(self.prize_template_start_time, 'to_alipay_dict'):
                params['prize_template_start_time'] = self.prize_template_start_time.to_alipay_dict()
            else:
                params['prize_template_start_time'] = self.prize_template_start_time
        if self.prize_terms:
            if isinstance(self.prize_terms, list):
                for i in range(0, len(self.prize_terms)):
                    element = self.prize_terms[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prize_terms[i] = element.to_alipay_dict()
            if hasattr(self.prize_terms, 'to_alipay_dict'):
                params['prize_terms'] = self.prize_terms.to_alipay_dict()
            else:
                params['prize_terms'] = self.prize_terms
        if self.prize_type:
            if hasattr(self.prize_type, 'to_alipay_dict'):
                params['prize_type'] = self.prize_type.to_alipay_dict()
            else:
                params['prize_type'] = self.prize_type
        if self.prize_worth_amount:
            if hasattr(self.prize_worth_amount, 'to_alipay_dict'):
                params['prize_worth_amount'] = self.prize_worth_amount.to_alipay_dict()
            else:
                params['prize_worth_amount'] = self.prize_worth_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenPromoPrize()
        if 'prize_base_rule_amount' in d:
            o.prize_base_rule_amount = d['prize_base_rule_amount']
        if 'prize_custom_menu' in d:
            o.prize_custom_menu = d['prize_custom_menu']
        if 'prize_desc' in d:
            o.prize_desc = d['prize_desc']
        if 'prize_detail_img' in d:
            o.prize_detail_img = d['prize_detail_img']
        if 'prize_dimension_time' in d:
            o.prize_dimension_time = d['prize_dimension_time']
        if 'prize_end_time' in d:
            o.prize_end_time = d['prize_end_time']
        if 'prize_logo' in d:
            o.prize_logo = d['prize_logo']
        if 'prize_name' in d:
            o.prize_name = d['prize_name']
        if 'prize_relative_time' in d:
            o.prize_relative_time = d['prize_relative_time']
        if 'prize_start_time' in d:
            o.prize_start_time = d['prize_start_time']
        if 'prize_subtitle' in d:
            o.prize_subtitle = d['prize_subtitle']
        if 'prize_suitable_shops' in d:
            o.prize_suitable_shops = d['prize_suitable_shops']
        if 'prize_template_end_time' in d:
            o.prize_template_end_time = d['prize_template_end_time']
        if 'prize_template_start_time' in d:
            o.prize_template_start_time = d['prize_template_start_time']
        if 'prize_terms' in d:
            o.prize_terms = d['prize_terms']
        if 'prize_type' in d:
            o.prize_type = d['prize_type']
        if 'prize_worth_amount' in d:
            o.prize_worth_amount = d['prize_worth_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CampaignExtInfo(object):

    def __init__(self):
        self._interval_time = None
        self._month_limit = None
        self._threshold = None

    @property
    def interval_time(self):
        return self._interval_time

    @interval_time.setter
    def interval_time(self, value):
        self._interval_time = value
    @property
    def month_limit(self):
        return self._month_limit

    @month_limit.setter
    def month_limit(self, value):
        self._month_limit = value
    @property
    def threshold(self):
        return self._threshold

    @threshold.setter
    def threshold(self, value):
        self._threshold = value


    def to_alipay_dict(self):
        params = dict()
        if self.interval_time:
            if hasattr(self.interval_time, 'to_alipay_dict'):
                params['interval_time'] = self.interval_time.to_alipay_dict()
            else:
                params['interval_time'] = self.interval_time
        if self.month_limit:
            if hasattr(self.month_limit, 'to_alipay_dict'):
                params['month_limit'] = self.month_limit.to_alipay_dict()
            else:
                params['month_limit'] = self.month_limit
        if self.threshold:
            if hasattr(self.threshold, 'to_alipay_dict'):
                params['threshold'] = self.threshold.to_alipay_dict()
            else:
                params['threshold'] = self.threshold
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CampaignExtInfo()
        if 'interval_time' in d:
            o.interval_time = d['interval_time']
        if 'month_limit' in d:
            o.month_limit = d['month_limit']
        if 'threshold' in d:
            o.threshold = d['threshold']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishCommRuleInfo import KbdishCommRuleInfo


class KoubeiCateringDishCommruleSyncModel(object):

    def __init__(self):
        self._kbdish_comm_rule_info_list = None

    @property
    def kbdish_comm_rule_info_list(self):
        return self._kbdish_comm_rule_info_list

    @kbdish_comm_rule_info_list.setter
    def kbdish_comm_rule_info_list(self, value):
        if isinstance(value, list):
            self._kbdish_comm_rule_info_list = list()
            for i in value:
                if isinstance(i, KbdishCommRuleInfo):
                    self._kbdish_comm_rule_info_list.append(i)
                else:
                    self._kbdish_comm_rule_info_list.append(KbdishCommRuleInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.kbdish_comm_rule_info_list:
            if isinstance(self.kbdish_comm_rule_info_list, list):
                for i in range(0, len(self.kbdish_comm_rule_info_list)):
                    element = self.kbdish_comm_rule_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.kbdish_comm_rule_info_list[i] = element.to_alipay_dict()
            if hasattr(self.kbdish_comm_rule_info_list, 'to_alipay_dict'):
                params['kbdish_comm_rule_info_list'] = self.kbdish_comm_rule_info_list.to_alipay_dict()
            else:
                params['kbdish_comm_rule_info_list'] = self.kbdish_comm_rule_info_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishCommruleSyncModel()
        if 'kbdish_comm_rule_info_list' in d:
            o.kbdish_comm_rule_info_list = d['kbdish_comm_rule_info_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMsaasSyncSingledataSendModel(object):

    def __init__(self):
        self._app_max_version = None
        self._app_min_version = None
        self._binary_payload = None
        self._biz_tag = None
        self._biz_type = None
        self._client_app = None
        self._device_id = None
        self._immediate_sync = None
        self._link_token = None
        self._os_type = None
        self._payload = None
        self._third_msg_id = None
        self._valid_end = None
        self._valid_start = None

    @property
    def app_max_version(self):
        return self._app_max_version

    @app_max_version.setter
    def app_max_version(self, value):
        self._app_max_version = value
    @property
    def app_min_version(self):
        return self._app_min_version

    @app_min_version.setter
    def app_min_version(self, value):
        self._app_min_version = value
    @property
    def binary_payload(self):
        return self._binary_payload

    @binary_payload.setter
    def binary_payload(self, value):
        self._binary_payload = value
    @property
    def biz_tag(self):
        return self._biz_tag

    @biz_tag.setter
    def biz_tag(self, value):
        self._biz_tag = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def client_app(self):
        return self._client_app

    @client_app.setter
    def client_app(self, value):
        self._client_app = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def immediate_sync(self):
        return self._immediate_sync

    @immediate_sync.setter
    def immediate_sync(self, value):
        self._immediate_sync = value
    @property
    def link_token(self):
        return self._link_token

    @link_token.setter
    def link_token(self, value):
        self._link_token = value
    @property
    def os_type(self):
        return self._os_type

    @os_type.setter
    def os_type(self, value):
        self._os_type = value
    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        self._payload = value
    @property
    def third_msg_id(self):
        return self._third_msg_id

    @third_msg_id.setter
    def third_msg_id(self, value):
        self._third_msg_id = value
    @property
    def valid_end(self):
        return self._valid_end

    @valid_end.setter
    def valid_end(self, value):
        self._valid_end = value
    @property
    def valid_start(self):
        return self._valid_start

    @valid_start.setter
    def valid_start(self, value):
        self._valid_start = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_max_version:
            if hasattr(self.app_max_version, 'to_alipay_dict'):
                params['app_max_version'] = self.app_max_version.to_alipay_dict()
            else:
                params['app_max_version'] = self.app_max_version
        if self.app_min_version:
            if hasattr(self.app_min_version, 'to_alipay_dict'):
                params['app_min_version'] = self.app_min_version.to_alipay_dict()
            else:
                params['app_min_version'] = self.app_min_version
        if self.binary_payload:
            if hasattr(self.binary_payload, 'to_alipay_dict'):
                params['binary_payload'] = self.binary_payload.to_alipay_dict()
            else:
                params['binary_payload'] = self.binary_payload
        if self.biz_tag:
            if hasattr(self.biz_tag, 'to_alipay_dict'):
                params['biz_tag'] = self.biz_tag.to_alipay_dict()
            else:
                params['biz_tag'] = self.biz_tag
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.client_app:
            if hasattr(self.client_app, 'to_alipay_dict'):
                params['client_app'] = self.client_app.to_alipay_dict()
            else:
                params['client_app'] = self.client_app
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.immediate_sync:
            if hasattr(self.immediate_sync, 'to_alipay_dict'):
                params['immediate_sync'] = self.immediate_sync.to_alipay_dict()
            else:
                params['immediate_sync'] = self.immediate_sync
        if self.link_token:
            if hasattr(self.link_token, 'to_alipay_dict'):
                params['link_token'] = self.link_token.to_alipay_dict()
            else:
                params['link_token'] = self.link_token
        if self.os_type:
            if hasattr(self.os_type, 'to_alipay_dict'):
                params['os_type'] = self.os_type.to_alipay_dict()
            else:
                params['os_type'] = self.os_type
        if self.payload:
            if hasattr(self.payload, 'to_alipay_dict'):
                params['payload'] = self.payload.to_alipay_dict()
            else:
                params['payload'] = self.payload
        if self.third_msg_id:
            if hasattr(self.third_msg_id, 'to_alipay_dict'):
                params['third_msg_id'] = self.third_msg_id.to_alipay_dict()
            else:
                params['third_msg_id'] = self.third_msg_id
        if self.valid_end:
            if hasattr(self.valid_end, 'to_alipay_dict'):
                params['valid_end'] = self.valid_end.to_alipay_dict()
            else:
                params['valid_end'] = self.valid_end
        if self.valid_start:
            if hasattr(self.valid_start, 'to_alipay_dict'):
                params['valid_start'] = self.valid_start.to_alipay_dict()
            else:
                params['valid_start'] = self.valid_start
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMsaasSyncSingledataSendModel()
        if 'app_max_version' in d:
            o.app_max_version = d['app_max_version']
        if 'app_min_version' in d:
            o.app_min_version = d['app_min_version']
        if 'binary_payload' in d:
            o.binary_payload = d['binary_payload']
        if 'biz_tag' in d:
            o.biz_tag = d['biz_tag']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'client_app' in d:
            o.client_app = d['client_app']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'immediate_sync' in d:
            o.immediate_sync = d['immediate_sync']
        if 'link_token' in d:
            o.link_token = d['link_token']
        if 'os_type' in d:
            o.os_type = d['os_type']
        if 'payload' in d:
            o.payload = d['payload']
        if 'third_msg_id' in d:
            o.third_msg_id = d['third_msg_id']
        if 'valid_end' in d:
            o.valid_end = d['valid_end']
        if 'valid_start' in d:
            o.valid_start = d['valid_start']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SecuritydataMobileCity import SecuritydataMobileCity


class AlipaySecurityDataInfoMobilecityQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityDataInfoMobilecityQueryResponse, self).__init__()
        self._mobile_city = None

    @property
    def mobile_city(self):
        return self._mobile_city

    @mobile_city.setter
    def mobile_city(self, value):
        if isinstance(value, SecuritydataMobileCity):
            self._mobile_city = value
        else:
            self._mobile_city = SecuritydataMobileCity.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityDataInfoMobilecityQueryResponse, self).parse_response_content(response_content)
        if 'mobile_city' in response:
            self.mobile_city = response['mobile_city']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PartnerVO import PartnerVO


class KoubeiRetailWmsPartnerQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiRetailWmsPartnerQueryResponse, self).__init__()
        self._partners = None
        self._total_count = None

    @property
    def partners(self):
        return self._partners

    @partners.setter
    def partners(self, value):
        if isinstance(value, list):
            self._partners = list()
            for i in value:
                if isinstance(i, PartnerVO):
                    self._partners.append(i)
                else:
                    self._partners.append(PartnerVO.from_alipay_dict(i))
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(KoubeiRetailWmsPartnerQueryResponse, self).parse_response_content(response_content)
        if 'partners' in response:
            self.partners = response['partners']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EnterpriseInfoDTO(object):

    def __init__(self):
        self._account_id = None
        self._activate = None
        self._auth_level = None
        self._auth_status = None
        self._auth_time = None
        self._enterprise_alias = None
        self._enterprise_code = None
        self._enterprise_email = None
        self._enterprise_id = None
        self._enterprise_name = None
        self._gmt_create = None
        self._gmt_modified = None
        self._iot_group_id = None
        self._iot_logic_group_id = None
        self._platform_code = None
        self._platform_out_id = None
        self._sign_status = None
        self._status = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def activate(self):
        return self._activate

    @activate.setter
    def activate(self, value):
        self._activate = value
    @property
    def auth_level(self):
        return self._auth_level

    @auth_level.setter
    def auth_level(self, value):
        self._auth_level = value
    @property
    def auth_status(self):
        return self._auth_status

    @auth_status.setter
    def auth_status(self, value):
        self._auth_status = value
    @property
    def auth_time(self):
        return self._auth_time

    @auth_time.setter
    def auth_time(self, value):
        self._auth_time = value
    @property
    def enterprise_alias(self):
        return self._enterprise_alias

    @enterprise_alias.setter
    def enterprise_alias(self, value):
        self._enterprise_alias = value
    @property
    def enterprise_code(self):
        return self._enterprise_code

    @enterprise_code.setter
    def enterprise_code(self, value):
        self._enterprise_code = value
    @property
    def enterprise_email(self):
        return self._enterprise_email

    @enterprise_email.setter
    def enterprise_email(self, value):
        self._enterprise_email = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def enterprise_name(self):
        return self._enterprise_name

    @enterprise_name.setter
    def enterprise_name(self, value):
        self._enterprise_name = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def iot_group_id(self):
        return self._iot_group_id

    @iot_group_id.setter
    def iot_group_id(self, value):
        self._iot_group_id = value
    @property
    def iot_logic_group_id(self):
        return self._iot_logic_group_id

    @iot_logic_group_id.setter
    def iot_logic_group_id(self, value):
        self._iot_logic_group_id = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def platform_out_id(self):
        return self._platform_out_id

    @platform_out_id.setter
    def platform_out_id(self, value):
        self._platform_out_id = value
    @property
    def sign_status(self):
        return self._sign_status

    @sign_status.setter
    def sign_status(self, value):
        self._sign_status = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.activate:
            if hasattr(self.activate, 'to_alipay_dict'):
                params['activate'] = self.activate.to_alipay_dict()
            else:
                params['activate'] = self.activate
        if self.auth_level:
            if hasattr(self.auth_level, 'to_alipay_dict'):
                params['auth_level'] = self.auth_level.to_alipay_dict()
            else:
                params['auth_level'] = self.auth_level
        if self.auth_status:
            if hasattr(self.auth_status, 'to_alipay_dict'):
                params['auth_status'] = self.auth_status.to_alipay_dict()
            else:
                params['auth_status'] = self.auth_status
        if self.auth_time:
            if hasattr(self.auth_time, 'to_alipay_dict'):
                params['auth_time'] = self.auth_time.to_alipay_dict()
            else:
                params['auth_time'] = self.auth_time
        if self.enterprise_alias:
            if hasattr(self.enterprise_alias, 'to_alipay_dict'):
                params['enterprise_alias'] = self.enterprise_alias.to_alipay_dict()
            else:
                params['enterprise_alias'] = self.enterprise_alias
        if self.enterprise_code:
            if hasattr(self.enterprise_code, 'to_alipay_dict'):
                params['enterprise_code'] = self.enterprise_code.to_alipay_dict()
            else:
                params['enterprise_code'] = self.enterprise_code
        if self.enterprise_email:
            if hasattr(self.enterprise_email, 'to_alipay_dict'):
                params['enterprise_email'] = self.enterprise_email.to_alipay_dict()
            else:
                params['enterprise_email'] = self.enterprise_email
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.enterprise_name:
            if hasattr(self.enterprise_name, 'to_alipay_dict'):
                params['enterprise_name'] = self.enterprise_name.to_alipay_dict()
            else:
                params['enterprise_name'] = self.enterprise_name
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.iot_group_id:
            if hasattr(self.iot_group_id, 'to_alipay_dict'):
                params['iot_group_id'] = self.iot_group_id.to_alipay_dict()
            else:
                params['iot_group_id'] = self.iot_group_id
        if self.iot_logic_group_id:
            if hasattr(self.iot_logic_group_id, 'to_alipay_dict'):
                params['iot_logic_group_id'] = self.iot_logic_group_id.to_alipay_dict()
            else:
                params['iot_logic_group_id'] = self.iot_logic_group_id
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.platform_out_id:
            if hasattr(self.platform_out_id, 'to_alipay_dict'):
                params['platform_out_id'] = self.platform_out_id.to_alipay_dict()
            else:
                params['platform_out_id'] = self.platform_out_id
        if self.sign_status:
            if hasattr(self.sign_status, 'to_alipay_dict'):
                params['sign_status'] = self.sign_status.to_alipay_dict()
            else:
                params['sign_status'] = self.sign_status
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnterpriseInfoDTO()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'activate' in d:
            o.activate = d['activate']
        if 'auth_level' in d:
            o.auth_level = d['auth_level']
        if 'auth_status' in d:
            o.auth_status = d['auth_status']
        if 'auth_time' in d:
            o.auth_time = d['auth_time']
        if 'enterprise_alias' in d:
            o.enterprise_alias = d['enterprise_alias']
        if 'enterprise_code' in d:
            o.enterprise_code = d['enterprise_code']
        if 'enterprise_email' in d:
            o.enterprise_email = d['enterprise_email']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'enterprise_name' in d:
            o.enterprise_name = d['enterprise_name']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'iot_group_id' in d:
            o.iot_group_id = d['iot_group_id']
        if 'iot_logic_group_id' in d:
            o.iot_logic_group_id = d['iot_logic_group_id']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'platform_out_id' in d:
            o.platform_out_id = d['platform_out_id']
        if 'sign_status' in d:
            o.sign_status = d['sign_status']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundIdentitypayMemberQueryModel(object):

    def __init__(self):
        self._biz_scene = None
        self._identity = None
        self._identity_type = None
        self._open_id = None
        self._out_member_id = None
        self._out_org_id = None
        self._product_code = None
        self._sub_biz_scene = None
        self._user_id = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_member_id(self):
        return self._out_member_id

    @out_member_id.setter
    def out_member_id(self, value):
        self._out_member_id = value
    @property
    def out_org_id(self):
        return self._out_org_id

    @out_org_id.setter
    def out_org_id(self, value):
        self._out_org_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def sub_biz_scene(self):
        return self._sub_biz_scene

    @sub_biz_scene.setter
    def sub_biz_scene(self, value):
        self._sub_biz_scene = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_member_id:
            if hasattr(self.out_member_id, 'to_alipay_dict'):
                params['out_member_id'] = self.out_member_id.to_alipay_dict()
            else:
                params['out_member_id'] = self.out_member_id
        if self.out_org_id:
            if hasattr(self.out_org_id, 'to_alipay_dict'):
                params['out_org_id'] = self.out_org_id.to_alipay_dict()
            else:
                params['out_org_id'] = self.out_org_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.sub_biz_scene:
            if hasattr(self.sub_biz_scene, 'to_alipay_dict'):
                params['sub_biz_scene'] = self.sub_biz_scene.to_alipay_dict()
            else:
                params['sub_biz_scene'] = self.sub_biz_scene
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundIdentitypayMemberQueryModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_member_id' in d:
            o.out_member_id = d['out_member_id']
        if 'out_org_id' in d:
            o.out_org_id = d['out_org_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'sub_biz_scene' in d:
            o.sub_biz_scene = d['sub_biz_scene']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.UserInfomation import UserInfomation
from alipay.aop.api.domain.DiscountInfoData import DiscountInfoData
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.ItemOrderInfo import ItemOrderInfo
from alipay.aop.api.domain.OrderJourneyInfo import OrderJourneyInfo
from alipay.aop.api.domain.OrderLogisticsInformationRequest import OrderLogisticsInformationRequest
from alipay.aop.api.domain.OrderShopInfo import OrderShopInfo
from alipay.aop.api.domain.TicketInfo import TicketInfo
from alipay.aop.api.domain.TicketOrderInfo import TicketOrderInfo


class AlipayMerchantOrderSyncModel(object):

    def __init__(self):
        self._amount = None
        self._buyer_id = None
        self._buyer_info = None
        self._buyer_open_id = None
        self._discount_amount = None
        self._discount_info_list = None
        self._ext_info = None
        self._item_order_list = None
        self._journey_order_list = None
        self._logistics_info_list = None
        self._order_auth_code = None
        self._order_create_time = None
        self._order_modified_time = None
        self._order_pay_time = None
        self._order_type = None
        self._out_biz_no = None
        self._partner_id = None
        self._pay_amount = None
        self._pay_timeout_express = None
        self._record_id = None
        self._seller_id = None
        self._send_msg = None
        self._service_code = None
        self._shop_info = None
        self._source_app = None
        self._sync_content = None
        self._ticket_info = None
        self._ticket_order_list = None
        self._trade_no = None
        self._trade_type = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def buyer_info(self):
        return self._buyer_info

    @buyer_info.setter
    def buyer_info(self, value):
        if isinstance(value, UserInfomation):
            self._buyer_info = value
        else:
            self._buyer_info = UserInfomation.from_alipay_dict(value)
    @property
    def buyer_open_id(self):
        return self._buyer_open_id

    @buyer_open_id.setter
    def buyer_open_id(self, value):
        self._buyer_open_id = value
    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_info_list(self):
        return self._discount_info_list

    @discount_info_list.setter
    def discount_info_list(self, value):
        if isinstance(value, list):
            self._discount_info_list = list()
            for i in value:
                if isinstance(i, DiscountInfoData):
                    self._discount_info_list.append(i)
                else:
                    self._discount_info_list.append(DiscountInfoData.from_alipay_dict(i))
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def item_order_list(self):
        return self._item_order_list

    @item_order_list.setter
    def item_order_list(self, value):
        if isinstance(value, list):
            self._item_order_list = list()
            for i in value:
                if isinstance(i, ItemOrderInfo):
                    self._item_order_list.append(i)
                else:
                    self._item_order_list.append(ItemOrderInfo.from_alipay_dict(i))
    @property
    def journey_order_list(self):
        return self._journey_order_list

    @journey_order_list.setter
    def journey_order_list(self, value):
        if isinstance(value, list):
            self._journey_order_list = list()
            for i in value:
                if isinstance(i, OrderJourneyInfo):
                    self._journey_order_list.append(i)
                else:
                    self._journey_order_list.append(OrderJourneyInfo.from_alipay_dict(i))
    @property
    def logistics_info_list(self):
        return self._logistics_info_list

    @logistics_info_list.setter
    def logistics_info_list(self, value):
        if isinstance(value, list):
            self._logistics_info_list = list()
            for i in value:
                if isinstance(i, OrderLogisticsInformationRequest):
                    self._logistics_info_list.append(i)
                else:
                    self._logistics_info_list.append(OrderLogisticsInformationRequest.from_alipay_dict(i))
    @property
    def order_auth_code(self):
        return self._order_auth_code

    @order_auth_code.setter
    def order_auth_code(self, value):
        self._order_auth_code = value
    @property
    def order_create_time(self):
        return self._order_create_time

    @order_create_time.setter
    def order_create_time(self, value):
        self._order_create_time = value
    @property
    def order_modified_time(self):
        return self._order_modified_time

    @order_modified_time.setter
    def order_modified_time(self, value):
        self._order_modified_time = value
    @property
    def order_pay_time(self):
        return self._order_pay_time

    @order_pay_time.setter
    def order_pay_time(self, value):
        self._order_pay_time = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_timeout_express(self):
        return self._pay_timeout_express

    @pay_timeout_express.setter
    def pay_timeout_express(self, value):
        self._pay_timeout_express = value
    @property
    def record_id(self):
        return self._record_id

    @record_id.setter
    def record_id(self, value):
        self._record_id = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def send_msg(self):
        return self._send_msg

    @send_msg.setter
    def send_msg(self, value):
        self._send_msg = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def shop_info(self):
        return self._shop_info

    @shop_info.setter
    def shop_info(self, value):
        if isinstance(value, OrderShopInfo):
            self._shop_info = value
        else:
            self._shop_info = OrderShopInfo.from_alipay_dict(value)
    @property
    def source_app(self):
        return self._source_app

    @source_app.setter
    def source_app(self, value):
        self._source_app = value
    @property
    def sync_content(self):
        return self._sync_content

    @sync_content.setter
    def sync_content(self, value):
        self._sync_content = value
    @property
    def ticket_info(self):
        return self._ticket_info

    @ticket_info.setter
    def ticket_info(self, value):
        if isinstance(value, TicketInfo):
            self._ticket_info = value
        else:
            self._ticket_info = TicketInfo.from_alipay_dict(value)
    @property
    def ticket_order_list(self):
        return self._ticket_order_list

    @ticket_order_list.setter
    def ticket_order_list(self, value):
        if isinstance(value, list):
            self._ticket_order_list = list()
            for i in value:
                if isinstance(i, TicketOrderInfo):
                    self._ticket_order_list.append(i)
                else:
                    self._ticket_order_list.append(TicketOrderInfo.from_alipay_dict(i))
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.buyer_info:
            if hasattr(self.buyer_info, 'to_alipay_dict'):
                params['buyer_info'] = self.buyer_info.to_alipay_dict()
            else:
                params['buyer_info'] = self.buyer_info
        if self.buyer_open_id:
            if hasattr(self.buyer_open_id, 'to_alipay_dict'):
                params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
            else:
                params['buyer_open_id'] = self.buyer_open_id
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_info_list:
            if isinstance(self.discount_info_list, list):
                for i in range(0, len(self.discount_info_list)):
                    element = self.discount_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.discount_info_list[i] = element.to_alipay_dict()
            if hasattr(self.discount_info_list, 'to_alipay_dict'):
                params['discount_info_list'] = self.discount_info_list.to_alipay_dict()
            else:
                params['discount_info_list'] = self.discount_info_list
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.item_order_list:
            if isinstance(self.item_order_list, list):
                for i in range(0, len(self.item_order_list)):
                    element = self.item_order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_order_list[i] = element.to_alipay_dict()
            if hasattr(self.item_order_list, 'to_alipay_dict'):
                params['item_order_list'] = self.item_order_list.to_alipay_dict()
            else:
                params['item_order_list'] = self.item_order_list
        if self.journey_order_list:
            if isinstance(self.journey_order_list, list):
                for i in range(0, len(self.journey_order_list)):
                    element = self.journey_order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.journey_order_list[i] = element.to_alipay_dict()
            if hasattr(self.journey_order_list, 'to_alipay_dict'):
                params['journey_order_list'] = self.journey_order_list.to_alipay_dict()
            else:
                params['journey_order_list'] = self.journey_order_list
        if self.logistics_info_list:
            if isinstance(self.logistics_info_list, list):
                for i in range(0, len(self.logistics_info_list)):
                    element = self.logistics_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logistics_info_list[i] = element.to_alipay_dict()
            if hasattr(self.logistics_info_list, 'to_alipay_dict'):
                params['logistics_info_list'] = self.logistics_info_list.to_alipay_dict()
            else:
                params['logistics_info_list'] = self.logistics_info_list
        if self.order_auth_code:
            if hasattr(self.order_auth_code, 'to_alipay_dict'):
                params['order_auth_code'] = self.order_auth_code.to_alipay_dict()
            else:
                params['order_auth_code'] = self.order_auth_code
        if self.order_create_time:
            if hasattr(self.order_create_time, 'to_alipay_dict'):
                params['order_create_time'] = self.order_create_time.to_alipay_dict()
            else:
                params['order_create_time'] = self.order_create_time
        if self.order_modified_time:
            if hasattr(self.order_modified_time, 'to_alipay_dict'):
                params['order_modified_time'] = self.order_modified_time.to_alipay_dict()
            else:
                params['order_modified_time'] = self.order_modified_time
        if self.order_pay_time:
            if hasattr(self.order_pay_time, 'to_alipay_dict'):
                params['order_pay_time'] = self.order_pay_time.to_alipay_dict()
            else:
                params['order_pay_time'] = self.order_pay_time
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pay_timeout_express:
            if hasattr(self.pay_timeout_express, 'to_alipay_dict'):
                params['pay_timeout_express'] = self.pay_timeout_express.to_alipay_dict()
            else:
                params['pay_timeout_express'] = self.pay_timeout_express
        if self.record_id:
            if hasattr(self.record_id, 'to_alipay_dict'):
                params['record_id'] = self.record_id.to_alipay_dict()
            else:
                params['record_id'] = self.record_id
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.send_msg:
            if hasattr(self.send_msg, 'to_alipay_dict'):
                params['send_msg'] = self.send_msg.to_alipay_dict()
            else:
                params['send_msg'] = self.send_msg
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.shop_info:
            if hasattr(self.shop_info, 'to_alipay_dict'):
                params['shop_info'] = self.shop_info.to_alipay_dict()
            else:
                params['shop_info'] = self.shop_info
        if self.source_app:
            if hasattr(self.source_app, 'to_alipay_dict'):
                params['source_app'] = self.source_app.to_alipay_dict()
            else:
                params['source_app'] = self.source_app
        if self.sync_content:
            if hasattr(self.sync_content, 'to_alipay_dict'):
                params['sync_content'] = self.sync_content.to_alipay_dict()
            else:
                params['sync_content'] = self.sync_content
        if self.ticket_info:
            if hasattr(self.ticket_info, 'to_alipay_dict'):
                params['ticket_info'] = self.ticket_info.to_alipay_dict()
            else:
                params['ticket_info'] = self.ticket_info
        if self.ticket_order_list:
            if isinstance(self.ticket_order_list, list):
                for i in range(0, len(self.ticket_order_list)):
                    element = self.ticket_order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ticket_order_list[i] = element.to_alipay_dict()
            if hasattr(self.ticket_order_list, 'to_alipay_dict'):
                params['ticket_order_list'] = self.ticket_order_list.to_alipay_dict()
            else:
                params['ticket_order_list'] = self.ticket_order_list
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderSyncModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'buyer_info' in d:
            o.buyer_info = d['buyer_info']
        if 'buyer_open_id' in d:
            o.buyer_open_id = d['buyer_open_id']
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_info_list' in d:
            o.discount_info_list = d['discount_info_list']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'item_order_list' in d:
            o.item_order_list = d['item_order_list']
        if 'journey_order_list' in d:
            o.journey_order_list = d['journey_order_list']
        if 'logistics_info_list' in d:
            o.logistics_info_list = d['logistics_info_list']
        if 'order_auth_code' in d:
            o.order_auth_code = d['order_auth_code']
        if 'order_create_time' in d:
            o.order_create_time = d['order_create_time']
        if 'order_modified_time' in d:
            o.order_modified_time = d['order_modified_time']
        if 'order_pay_time' in d:
            o.order_pay_time = d['order_pay_time']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pay_timeout_express' in d:
            o.pay_timeout_express = d['pay_timeout_express']
        if 'record_id' in d:
            o.record_id = d['record_id']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'send_msg' in d:
            o.send_msg = d['send_msg']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'shop_info' in d:
            o.shop_info = d['shop_info']
        if 'source_app' in d:
            o.source_app = d['source_app']
        if 'sync_content' in d:
            o.sync_content = d['sync_content']
        if 'ticket_info' in d:
            o.ticket_info = d['ticket_info']
        if 'ticket_order_list' in d:
            o.ticket_order_list = d['ticket_order_list']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneEcommercePreorderCloseModel(object):

    def __init__(self):
        self._order_id = None
        self._partner_org_id = None
        self._pre_order_ids = None

    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def partner_org_id(self):
        return self._partner_org_id

    @partner_org_id.setter
    def partner_org_id(self, value):
        self._partner_org_id = value
    @property
    def pre_order_ids(self):
        return self._pre_order_ids

    @pre_order_ids.setter
    def pre_order_ids(self, value):
        if isinstance(value, list):
            self._pre_order_ids = list()
            for i in value:
                self._pre_order_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.partner_org_id:
            if hasattr(self.partner_org_id, 'to_alipay_dict'):
                params['partner_org_id'] = self.partner_org_id.to_alipay_dict()
            else:
                params['partner_org_id'] = self.partner_org_id
        if self.pre_order_ids:
            if isinstance(self.pre_order_ids, list):
                for i in range(0, len(self.pre_order_ids)):
                    element = self.pre_order_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pre_order_ids[i] = element.to_alipay_dict()
            if hasattr(self.pre_order_ids, 'to_alipay_dict'):
                params['pre_order_ids'] = self.pre_order_ids.to_alipay_dict()
            else:
                params['pre_order_ids'] = self.pre_order_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneEcommercePreorderCloseModel()
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'partner_org_id' in d:
            o.partner_org_id = d['partner_org_id']
        if 'pre_order_ids' in d:
            o.pre_order_ids = d['pre_order_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MEquityValidInfo(object):

    def __init__(self):
        self._delay_minutes = None
        self._effect_type = None
        self._end_date = None
        self._relative_minutes = None
        self._start_date = None
        self._valid_type = None

    @property
    def delay_minutes(self):
        return self._delay_minutes

    @delay_minutes.setter
    def delay_minutes(self, value):
        self._delay_minutes = value
    @property
    def effect_type(self):
        return self._effect_type

    @effect_type.setter
    def effect_type(self, value):
        self._effect_type = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def relative_minutes(self):
        return self._relative_minutes

    @relative_minutes.setter
    def relative_minutes(self, value):
        self._relative_minutes = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def valid_type(self):
        return self._valid_type

    @valid_type.setter
    def valid_type(self, value):
        self._valid_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.delay_minutes:
            if hasattr(self.delay_minutes, 'to_alipay_dict'):
                params['delay_minutes'] = self.delay_minutes.to_alipay_dict()
            else:
                params['delay_minutes'] = self.delay_minutes
        if self.effect_type:
            if hasattr(self.effect_type, 'to_alipay_dict'):
                params['effect_type'] = self.effect_type.to_alipay_dict()
            else:
                params['effect_type'] = self.effect_type
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.relative_minutes:
            if hasattr(self.relative_minutes, 'to_alipay_dict'):
                params['relative_minutes'] = self.relative_minutes.to_alipay_dict()
            else:
                params['relative_minutes'] = self.relative_minutes
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.valid_type:
            if hasattr(self.valid_type, 'to_alipay_dict'):
                params['valid_type'] = self.valid_type.to_alipay_dict()
            else:
                params['valid_type'] = self.valid_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MEquityValidInfo()
        if 'delay_minutes' in d:
            o.delay_minutes = d['delay_minutes']
        if 'effect_type' in d:
            o.effect_type = d['effect_type']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'relative_minutes' in d:
            o.relative_minutes = d['relative_minutes']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'valid_type' in d:
            o.valid_type = d['valid_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InventoryRecord(object):

    def __init__(self):
        self._after_modify_lock_quantity = None
        self._after_modify_quantity = None
        self._batch_code = None
        self._before_modify_lock_quantity = None
        self._before_modify_quantity = None
        self._diff_lock_quantity = None
        self._diff_quantity = None
        self._expire_date = None
        self._gmt_create = None
        self._gmt_modified = None
        self._goods_code = None
        self._inventory_type = None
        self._operate_type = None
        self._out_biz_id = None
        self._product_date = None
        self._remark = None
        self._warehouse_code = None

    @property
    def after_modify_lock_quantity(self):
        return self._after_modify_lock_quantity

    @after_modify_lock_quantity.setter
    def after_modify_lock_quantity(self, value):
        self._after_modify_lock_quantity = value
    @property
    def after_modify_quantity(self):
        return self._after_modify_quantity

    @after_modify_quantity.setter
    def after_modify_quantity(self, value):
        self._after_modify_quantity = value
    @property
    def batch_code(self):
        return self._batch_code

    @batch_code.setter
    def batch_code(self, value):
        self._batch_code = value
    @property
    def before_modify_lock_quantity(self):
        return self._before_modify_lock_quantity

    @before_modify_lock_quantity.setter
    def before_modify_lock_quantity(self, value):
        self._before_modify_lock_quantity = value
    @property
    def before_modify_quantity(self):
        return self._before_modify_quantity

    @before_modify_quantity.setter
    def before_modify_quantity(self, value):
        self._before_modify_quantity = value
    @property
    def diff_lock_quantity(self):
        return self._diff_lock_quantity

    @diff_lock_quantity.setter
    def diff_lock_quantity(self, value):
        self._diff_lock_quantity = value
    @property
    def diff_quantity(self):
        return self._diff_quantity

    @diff_quantity.setter
    def diff_quantity(self, value):
        self._diff_quantity = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def goods_code(self):
        return self._goods_code

    @goods_code.setter
    def goods_code(self, value):
        self._goods_code = value
    @property
    def inventory_type(self):
        return self._inventory_type

    @inventory_type.setter
    def inventory_type(self, value):
        self._inventory_type = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value
    @property
    def product_date(self):
        return self._product_date

    @product_date.setter
    def product_date(self, value):
        self._product_date = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def warehouse_code(self):
        return self._warehouse_code

    @warehouse_code.setter
    def warehouse_code(self, value):
        self._warehouse_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.after_modify_lock_quantity:
            if hasattr(self.after_modify_lock_quantity, 'to_alipay_dict'):
                params['after_modify_lock_quantity'] = self.after_modify_lock_quantity.to_alipay_dict()
            else:
                params['after_modify_lock_quantity'] = self.after_modify_lock_quantity
        if self.after_modify_quantity:
            if hasattr(self.after_modify_quantity, 'to_alipay_dict'):
                params['after_modify_quantity'] = self.after_modify_quantity.to_alipay_dict()
            else:
                params['after_modify_quantity'] = self.after_modify_quantity
        if self.batch_code:
            if hasattr(self.batch_code, 'to_alipay_dict'):
                params['batch_code'] = self.batch_code.to_alipay_dict()
            else:
                params['batch_code'] = self.batch_code
        if self.before_modify_lock_quantity:
            if hasattr(self.before_modify_lock_quantity, 'to_alipay_dict'):
                params['before_modify_lock_quantity'] = self.before_modify_lock_quantity.to_alipay_dict()
            else:
                params['before_modify_lock_quantity'] = self.before_modify_lock_quantity
        if self.before_modify_quantity:
            if hasattr(self.before_modify_quantity, 'to_alipay_dict'):
                params['before_modify_quantity'] = self.before_modify_quantity.to_alipay_dict()
            else:
                params['before_modify_quantity'] = self.before_modify_quantity
        if self.diff_lock_quantity:
            if hasattr(self.diff_lock_quantity, 'to_alipay_dict'):
                params['diff_lock_quantity'] = self.diff_lock_quantity.to_alipay_dict()
            else:
                params['diff_lock_quantity'] = self.diff_lock_quantity
        if self.diff_quantity:
            if hasattr(self.diff_quantity, 'to_alipay_dict'):
                params['diff_quantity'] = self.diff_quantity.to_alipay_dict()
            else:
                params['diff_quantity'] = self.diff_quantity
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.goods_code:
            if hasattr(self.goods_code, 'to_alipay_dict'):
                params['goods_code'] = self.goods_code.to_alipay_dict()
            else:
                params['goods_code'] = self.goods_code
        if self.inventory_type:
            if hasattr(self.inventory_type, 'to_alipay_dict'):
                params['inventory_type'] = self.inventory_type.to_alipay_dict()
            else:
                params['inventory_type'] = self.inventory_type
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        if self.product_date:
            if hasattr(self.product_date, 'to_alipay_dict'):
                params['product_date'] = self.product_date.to_alipay_dict()
            else:
                params['product_date'] = self.product_date
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.warehouse_code:
            if hasattr(self.warehouse_code, 'to_alipay_dict'):
                params['warehouse_code'] = self.warehouse_code.to_alipay_dict()
            else:
                params['warehouse_code'] = self.warehouse_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InventoryRecord()
        if 'after_modify_lock_quantity' in d:
            o.after_modify_lock_quantity = d['after_modify_lock_quantity']
        if 'after_modify_quantity' in d:
            o.after_modify_quantity = d['after_modify_quantity']
        if 'batch_code' in d:
            o.batch_code = d['batch_code']
        if 'before_modify_lock_quantity' in d:
            o.before_modify_lock_quantity = d['before_modify_lock_quantity']
        if 'before_modify_quantity' in d:
            o.before_modify_quantity = d['before_modify_quantity']
        if 'diff_lock_quantity' in d:
            o.diff_lock_quantity = d['diff_lock_quantity']
        if 'diff_quantity' in d:
            o.diff_quantity = d['diff_quantity']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'goods_code' in d:
            o.goods_code = d['goods_code']
        if 'inventory_type' in d:
            o.inventory_type = d['inventory_type']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        if 'product_date' in d:
            o.product_date = d['product_date']
        if 'remark' in d:
            o.remark = d['remark']
        if 'warehouse_code' in d:
            o.warehouse_code = d['warehouse_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaMerchantOrderRentCreateResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaMerchantOrderRentCreateResponse, self).__init__()
        self._admit_state = None
        self._invoke_state = None
        self._open_id = None
        self._order_no = None
        self._out_order_no = None
        self._user_id = None

    @property
    def admit_state(self):
        return self._admit_state

    @admit_state.setter
    def admit_state(self, value):
        self._admit_state = value
    @property
    def invoke_state(self):
        return self._invoke_state

    @invoke_state.setter
    def invoke_state(self, value):
        self._invoke_state = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(ZhimaMerchantOrderRentCreateResponse, self).parse_response_content(response_content)
        if 'admit_state' in response:
            self.admit_state = response['admit_state']
        if 'invoke_state' in response:
            self.invoke_state = response['invoke_state']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMerchantPayforprivilegePayCreateModel(object):

    def __init__(self):
        self._member_id = None
        self._open_id = None
        self._out_biz_no = None
        self._payer_user_id = None
        self._promotion_plan_id = None
        self._recharge_amount = None
        self._user_id = None

    @property
    def member_id(self):
        return self._member_id

    @member_id.setter
    def member_id(self, value):
        self._member_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def payer_user_id(self):
        return self._payer_user_id

    @payer_user_id.setter
    def payer_user_id(self, value):
        self._payer_user_id = value
    @property
    def promotion_plan_id(self):
        return self._promotion_plan_id

    @promotion_plan_id.setter
    def promotion_plan_id(self, value):
        self._promotion_plan_id = value
    @property
    def recharge_amount(self):
        return self._recharge_amount

    @recharge_amount.setter
    def recharge_amount(self, value):
        self._recharge_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.member_id:
            if hasattr(self.member_id, 'to_alipay_dict'):
                params['member_id'] = self.member_id.to_alipay_dict()
            else:
                params['member_id'] = self.member_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.payer_user_id:
            if hasattr(self.payer_user_id, 'to_alipay_dict'):
                params['payer_user_id'] = self.payer_user_id.to_alipay_dict()
            else:
                params['payer_user_id'] = self.payer_user_id
        if self.promotion_plan_id:
            if hasattr(self.promotion_plan_id, 'to_alipay_dict'):
                params['promotion_plan_id'] = self.promotion_plan_id.to_alipay_dict()
            else:
                params['promotion_plan_id'] = self.promotion_plan_id
        if self.recharge_amount:
            if hasattr(self.recharge_amount, 'to_alipay_dict'):
                params['recharge_amount'] = self.recharge_amount.to_alipay_dict()
            else:
                params['recharge_amount'] = self.recharge_amount
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantPayforprivilegePayCreateModel()
        if 'member_id' in d:
            o.member_id = d['member_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'payer_user_id' in d:
            o.payer_user_id = d['payer_user_id']
        if 'promotion_plan_id' in d:
            o.promotion_plan_id = d['promotion_plan_id']
        if 'recharge_amount' in d:
            o.recharge_amount = d['recharge_amount']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoEprintCodeNotifyModel(object):

    def __init__(self):
        self._code = None
        self._store_id = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEprintCodeNotifyModel()
        if 'code' in d:
            o.code = d['code']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceMedicalIndustrydataInquirydoctorUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceMedicalIndustrydataInquirydoctorUploadResponse, self).__init__()
        self._error_message = None
        self._result_code = None
        self._time = None

    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def time(self):
        return self._time

    @time.setter
    def time(self, value):
        self._time = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceMedicalIndustrydataInquirydoctorUploadResponse, self).parse_response_content(response_content)
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'time' in response:
            self.time = response['time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCertdocUrlQueryModel(object):

    def __init__(self):
        self._biz_type = None
        self._cert_doc_type = None
        self._city = None
        self._url_type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def cert_doc_type(self):
        return self._cert_doc_type

    @cert_doc_type.setter
    def cert_doc_type(self, value):
        self._cert_doc_type = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def url_type(self):
        return self._url_type

    @url_type.setter
    def url_type(self, value):
        self._url_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.cert_doc_type:
            if hasattr(self.cert_doc_type, 'to_alipay_dict'):
                params['cert_doc_type'] = self.cert_doc_type.to_alipay_dict()
            else:
                params['cert_doc_type'] = self.cert_doc_type
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.url_type:
            if hasattr(self.url_type, 'to_alipay_dict'):
                params['url_type'] = self.url_type.to_alipay_dict()
            else:
                params['url_type'] = self.url_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertdocUrlQueryModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'cert_doc_type' in d:
            o.cert_doc_type = d['cert_doc_type']
        if 'city' in d:
            o.city = d['city']
        if 'url_type' in d:
            o.url_type = d['url_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AiPictureVO(object):

    def __init__(self):
        self._image_id = None
        self._sec_status = None

    @property
    def image_id(self):
        return self._image_id

    @image_id.setter
    def image_id(self, value):
        self._image_id = value
    @property
    def sec_status(self):
        return self._sec_status

    @sec_status.setter
    def sec_status(self, value):
        self._sec_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.image_id:
            if hasattr(self.image_id, 'to_alipay_dict'):
                params['image_id'] = self.image_id.to_alipay_dict()
            else:
                params['image_id'] = self.image_id
        if self.sec_status:
            if hasattr(self.sec_status, 'to_alipay_dict'):
                params['sec_status'] = self.sec_status.to_alipay_dict()
            else:
                params['sec_status'] = self.sec_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AiPictureVO()
        if 'image_id' in d:
            o.image_id = d['image_id']
        if 'sec_status' in d:
            o.sec_status = d['sec_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SsdataDataserviceTestaaaSendModel(object):

    def __init__(self):
        self._tes_1 = None
        self._test_2 = None

    @property
    def tes_1(self):
        return self._tes_1

    @tes_1.setter
    def tes_1(self, value):
        self._tes_1 = value
    @property
    def test_2(self):
        return self._test_2

    @test_2.setter
    def test_2(self, value):
        self._test_2 = value


    def to_alipay_dict(self):
        params = dict()
        if self.tes_1:
            if hasattr(self.tes_1, 'to_alipay_dict'):
                params['tes_1'] = self.tes_1.to_alipay_dict()
            else:
                params['tes_1'] = self.tes_1
        if self.test_2:
            if hasattr(self.test_2, 'to_alipay_dict'):
                params['test_2'] = self.test_2.to_alipay_dict()
            else:
                params['test_2'] = self.test_2
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SsdataDataserviceTestaaaSendModel()
        if 'tes_1' in d:
            o.tes_1 = d['tes_1']
        if 'test_2' in d:
            o.test_2 = d['test_2']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniCloudFileQueryModel(object):

    def __init__(self):
        self._cloud_id = None
        self._file_id = None

    @property
    def cloud_id(self):
        return self._cloud_id

    @cloud_id.setter
    def cloud_id(self, value):
        self._cloud_id = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cloud_id:
            if hasattr(self.cloud_id, 'to_alipay_dict'):
                params['cloud_id'] = self.cloud_id.to_alipay_dict()
            else:
                params['cloud_id'] = self.cloud_id
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniCloudFileQueryModel()
        if 'cloud_id' in d:
            o.cloud_id = d['cloud_id']
        if 'file_id' in d:
            o.file_id = d['file_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainDefinDataserviceFileSubmitResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinDataserviceFileSubmitResponse, self).__init__()
        self._biz_result = None

    @property
    def biz_result(self):
        return self._biz_result

    @biz_result.setter
    def biz_result(self, value):
        self._biz_result = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinDataserviceFileSubmitResponse, self).parse_response_content(response_content)
        if 'biz_result' in response:
            self.biz_result = response['biz_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AlmReportData import AlmReportData


class AlipayDataDataserviceYuebaoassetDetailSendModel(object):

    def __init__(self):
        self._alm_report_data = None

    @property
    def alm_report_data(self):
        return self._alm_report_data

    @alm_report_data.setter
    def alm_report_data(self, value):
        if isinstance(value, list):
            self._alm_report_data = list()
            for i in value:
                if isinstance(i, AlmReportData):
                    self._alm_report_data.append(i)
                else:
                    self._alm_report_data.append(AlmReportData.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.alm_report_data:
            if isinstance(self.alm_report_data, list):
                for i in range(0, len(self.alm_report_data)):
                    element = self.alm_report_data[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.alm_report_data[i] = element.to_alipay_dict()
            if hasattr(self.alm_report_data, 'to_alipay_dict'):
                params['alm_report_data'] = self.alm_report_data.to_alipay_dict()
            else:
                params['alm_report_data'] = self.alm_report_data
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceYuebaoassetDetailSendModel()
        if 'alm_report_data' in d:
            o.alm_report_data = d['alm_report_data']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GroupFundsImcomeDetails import GroupFundsImcomeDetails


class AlipayFundTransGroupfundsBatchCreateModel(object):

    def __init__(self):
        self._current_user_id = None
        self._ext_param = None
        self._income_details = None
        self._out_biz_no = None
        self._source = None
        self._total_amount = None

    @property
    def current_user_id(self):
        return self._current_user_id

    @current_user_id.setter
    def current_user_id(self, value):
        self._current_user_id = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def income_details(self):
        return self._income_details

    @income_details.setter
    def income_details(self, value):
        if isinstance(value, list):
            self._income_details = list()
            for i in value:
                if isinstance(i, GroupFundsImcomeDetails):
                    self._income_details.append(i)
                else:
                    self._income_details.append(GroupFundsImcomeDetails.from_alipay_dict(i))
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_user_id:
            if hasattr(self.current_user_id, 'to_alipay_dict'):
                params['current_user_id'] = self.current_user_id.to_alipay_dict()
            else:
                params['current_user_id'] = self.current_user_id
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.income_details:
            if isinstance(self.income_details, list):
                for i in range(0, len(self.income_details)):
                    element = self.income_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.income_details[i] = element.to_alipay_dict()
            if hasattr(self.income_details, 'to_alipay_dict'):
                params['income_details'] = self.income_details.to_alipay_dict()
            else:
                params['income_details'] = self.income_details
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransGroupfundsBatchCreateModel()
        if 'current_user_id' in d:
            o.current_user_id = d['current_user_id']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'income_details' in d:
            o.income_details = d['income_details']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'source' in d:
            o.source = d['source']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandActivitySignupCreateResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandActivitySignupCreateResponse, self).__init__()
        self._desc = None
        self._pid = None
        self._status = None

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandActivitySignupCreateResponse, self).parse_response_content(response_content)
        if 'desc' in response:
            self.desc = response['desc']
        if 'pid' in response:
            self.pid = response['pid']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessBankAccountInfo(object):

    def __init__(self):
        self._business_bank_account_name = None
        self._business_bank_card_no = None
        self._business_bank_name = None
        self._business_bank_sub = None

    @property
    def business_bank_account_name(self):
        return self._business_bank_account_name

    @business_bank_account_name.setter
    def business_bank_account_name(self, value):
        self._business_bank_account_name = value
    @property
    def business_bank_card_no(self):
        return self._business_bank_card_no

    @business_bank_card_no.setter
    def business_bank_card_no(self, value):
        self._business_bank_card_no = value
    @property
    def business_bank_name(self):
        return self._business_bank_name

    @business_bank_name.setter
    def business_bank_name(self, value):
        self._business_bank_name = value
    @property
    def business_bank_sub(self):
        return self._business_bank_sub

    @business_bank_sub.setter
    def business_bank_sub(self, value):
        self._business_bank_sub = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_bank_account_name:
            if hasattr(self.business_bank_account_name, 'to_alipay_dict'):
                params['business_bank_account_name'] = self.business_bank_account_name.to_alipay_dict()
            else:
                params['business_bank_account_name'] = self.business_bank_account_name
        if self.business_bank_card_no:
            if hasattr(self.business_bank_card_no, 'to_alipay_dict'):
                params['business_bank_card_no'] = self.business_bank_card_no.to_alipay_dict()
            else:
                params['business_bank_card_no'] = self.business_bank_card_no
        if self.business_bank_name:
            if hasattr(self.business_bank_name, 'to_alipay_dict'):
                params['business_bank_name'] = self.business_bank_name.to_alipay_dict()
            else:
                params['business_bank_name'] = self.business_bank_name
        if self.business_bank_sub:
            if hasattr(self.business_bank_sub, 'to_alipay_dict'):
                params['business_bank_sub'] = self.business_bank_sub.to_alipay_dict()
            else:
                params['business_bank_sub'] = self.business_bank_sub
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessBankAccountInfo()
        if 'business_bank_account_name' in d:
            o.business_bank_account_name = d['business_bank_account_name']
        if 'business_bank_card_no' in d:
            o.business_bank_card_no = d['business_bank_card_no']
        if 'business_bank_name' in d:
            o.business_bank_name = d['business_bank_name']
        if 'business_bank_sub' in d:
            o.business_bank_sub = d['business_bank_sub']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpEntityMonitorSetModel(object):

    def __init__(self):
        self._contact_list = None
        self._solution_id = None

    @property
    def contact_list(self):
        return self._contact_list

    @contact_list.setter
    def contact_list(self, value):
        self._contact_list = value
    @property
    def solution_id(self):
        return self._solution_id

    @solution_id.setter
    def solution_id(self, value):
        self._solution_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.contact_list:
            if hasattr(self.contact_list, 'to_alipay_dict'):
                params['contact_list'] = self.contact_list.to_alipay_dict()
            else:
                params['contact_list'] = self.contact_list
        if self.solution_id:
            if hasattr(self.solution_id, 'to_alipay_dict'):
                params['solution_id'] = self.solution_id.to_alipay_dict()
            else:
                params['solution_id'] = self.solution_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpEntityMonitorSetModel()
        if 'contact_list' in d:
            o.contact_list = d['contact_list']
        if 'solution_id' in d:
            o.solution_id = d['solution_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundAccountbookCardQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundAccountbookCardQueryResponse, self).__init__()
        self._account_book_card_no = None
        self._available_amount = None
        self._bank_acc_name = None
        self._card_bank = None
        self._card_branch = None
        self._card_deposit = None
        self._card_location = None
        self._status = None

    @property
    def account_book_card_no(self):
        return self._account_book_card_no

    @account_book_card_no.setter
    def account_book_card_no(self, value):
        self._account_book_card_no = value
    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def bank_acc_name(self):
        return self._bank_acc_name

    @bank_acc_name.setter
    def bank_acc_name(self, value):
        self._bank_acc_name = value
    @property
    def card_bank(self):
        return self._card_bank

    @card_bank.setter
    def card_bank(self, value):
        self._card_bank = value
    @property
    def card_branch(self):
        return self._card_branch

    @card_branch.setter
    def card_branch(self, value):
        self._card_branch = value
    @property
    def card_deposit(self):
        return self._card_deposit

    @card_deposit.setter
    def card_deposit(self, value):
        self._card_deposit = value
    @property
    def card_location(self):
        return self._card_location

    @card_location.setter
    def card_location(self, value):
        self._card_location = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundAccountbookCardQueryResponse, self).parse_response_content(response_content)
        if 'account_book_card_no' in response:
            self.account_book_card_no = response['account_book_card_no']
        if 'available_amount' in response:
            self.available_amount = response['available_amount']
        if 'bank_acc_name' in response:
            self.bank_acc_name = response['bank_acc_name']
        if 'card_bank' in response:
            self.card_bank = response['card_bank']
        if 'card_branch' in response:
            self.card_branch = response['card_branch']
        if 'card_deposit' in response:
            self.card_deposit = response['card_deposit']
        if 'card_location' in response:
            self.card_location = response['card_location']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.WorkPatternDetail import WorkPatternDetail


class WorkPattern(object):

    def __init__(self):
        self._direction = None
        self._ext_param = None
        self._max_work_time = None
        self._work_count = None
        self._work_pattern_detail_list = None
        self._work_pattern_id = None

    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def max_work_time(self):
        return self._max_work_time

    @max_work_time.setter
    def max_work_time(self, value):
        self._max_work_time = value
    @property
    def work_count(self):
        return self._work_count

    @work_count.setter
    def work_count(self, value):
        self._work_count = value
    @property
    def work_pattern_detail_list(self):
        return self._work_pattern_detail_list

    @work_pattern_detail_list.setter
    def work_pattern_detail_list(self, value):
        if isinstance(value, list):
            self._work_pattern_detail_list = list()
            for i in value:
                if isinstance(i, WorkPatternDetail):
                    self._work_pattern_detail_list.append(i)
                else:
                    self._work_pattern_detail_list.append(WorkPatternDetail.from_alipay_dict(i))
    @property
    def work_pattern_id(self):
        return self._work_pattern_id

    @work_pattern_id.setter
    def work_pattern_id(self, value):
        self._work_pattern_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.max_work_time:
            if hasattr(self.max_work_time, 'to_alipay_dict'):
                params['max_work_time'] = self.max_work_time.to_alipay_dict()
            else:
                params['max_work_time'] = self.max_work_time
        if self.work_count:
            if hasattr(self.work_count, 'to_alipay_dict'):
                params['work_count'] = self.work_count.to_alipay_dict()
            else:
                params['work_count'] = self.work_count
        if self.work_pattern_detail_list:
            if isinstance(self.work_pattern_detail_list, list):
                for i in range(0, len(self.work_pattern_detail_list)):
                    element = self.work_pattern_detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.work_pattern_detail_list[i] = element.to_alipay_dict()
            if hasattr(self.work_pattern_detail_list, 'to_alipay_dict'):
                params['work_pattern_detail_list'] = self.work_pattern_detail_list.to_alipay_dict()
            else:
                params['work_pattern_detail_list'] = self.work_pattern_detail_list
        if self.work_pattern_id:
            if hasattr(self.work_pattern_id, 'to_alipay_dict'):
                params['work_pattern_id'] = self.work_pattern_id.to_alipay_dict()
            else:
                params['work_pattern_id'] = self.work_pattern_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = WorkPattern()
        if 'direction' in d:
            o.direction = d['direction']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'max_work_time' in d:
            o.max_work_time = d['max_work_time']
        if 'work_count' in d:
            o.work_count = d['work_count']
        if 'work_pattern_detail_list' in d:
            o.work_pattern_detail_list = d['work_pattern_detail_list']
        if 'work_pattern_id' in d:
            o.work_pattern_id = d['work_pattern_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccessProduceQrcode(object):

    def __init__(self):
        self._batch_id = None
        self._core_url = None
        self._produce_order_id = None
        self._qrcode = None

    @property
    def batch_id(self):
        return self._batch_id

    @batch_id.setter
    def batch_id(self, value):
        self._batch_id = value
    @property
    def core_url(self):
        return self._core_url

    @core_url.setter
    def core_url(self, value):
        self._core_url = value
    @property
    def produce_order_id(self):
        return self._produce_order_id

    @produce_order_id.setter
    def produce_order_id(self, value):
        self._produce_order_id = value
    @property
    def qrcode(self):
        return self._qrcode

    @qrcode.setter
    def qrcode(self, value):
        self._qrcode = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_id:
            if hasattr(self.batch_id, 'to_alipay_dict'):
                params['batch_id'] = self.batch_id.to_alipay_dict()
            else:
                params['batch_id'] = self.batch_id
        if self.core_url:
            if hasattr(self.core_url, 'to_alipay_dict'):
                params['core_url'] = self.core_url.to_alipay_dict()
            else:
                params['core_url'] = self.core_url
        if self.produce_order_id:
            if hasattr(self.produce_order_id, 'to_alipay_dict'):
                params['produce_order_id'] = self.produce_order_id.to_alipay_dict()
            else:
                params['produce_order_id'] = self.produce_order_id
        if self.qrcode:
            if hasattr(self.qrcode, 'to_alipay_dict'):
                params['qrcode'] = self.qrcode.to_alipay_dict()
            else:
                params['qrcode'] = self.qrcode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccessProduceQrcode()
        if 'batch_id' in d:
            o.batch_id = d['batch_id']
        if 'core_url' in d:
            o.core_url = d['core_url']
        if 'produce_order_id' in d:
            o.produce_order_id = d['produce_order_id']
        if 'qrcode' in d:
            o.qrcode = d['qrcode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEcJointaccountbillDetailBatchqueryModel(object):

    def __init__(self):
        self._biz_scene = None
        self._end_date = None
        self._enterprise_id = None
        self._open_id = None
        self._page_num = None
        self._page_size = None
        self._start_date = None
        self._user_id = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEcJointaccountbillDetailBatchqueryModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsPeriodDTO(object):

    def __init__(self):
        self._option_tag = None
        self._period = None
        self._recommend = None
        self._unit = None

    @property
    def option_tag(self):
        return self._option_tag

    @option_tag.setter
    def option_tag(self, value):
        self._option_tag = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def recommend(self):
        return self._recommend

    @recommend.setter
    def recommend(self, value):
        self._recommend = value
    @property
    def unit(self):
        return self._unit

    @unit.setter
    def unit(self, value):
        self._unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.option_tag:
            if hasattr(self.option_tag, 'to_alipay_dict'):
                params['option_tag'] = self.option_tag.to_alipay_dict()
            else:
                params['option_tag'] = self.option_tag
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.recommend:
            if hasattr(self.recommend, 'to_alipay_dict'):
                params['recommend'] = self.recommend.to_alipay_dict()
            else:
                params['recommend'] = self.recommend
        if self.unit:
            if hasattr(self.unit, 'to_alipay_dict'):
                params['unit'] = self.unit.to_alipay_dict()
            else:
                params['unit'] = self.unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsPeriodDTO()
        if 'option_tag' in d:
            o.option_tag = d['option_tag']
        if 'period' in d:
            o.period = d['period']
        if 'recommend' in d:
            o.recommend = d['recommend']
        if 'unit' in d:
            o.unit = d['unit']
        return o


